==> gazie7.30.zip: gazie/modules/contab/menu.english.php <==
<?php
/*
  --------------------------------------------------------------------------
  GAzie - Gestione Azienda
  Copyright (C) 2004-2020 - Antonio De Vincentiis Montesilvano (PE)
  (http://www.devincentiis.it)
  <http://gazie.sourceforge.net>
  --------------------------------------------------------------------------
  Questo programma e` free software;   e` lecito redistribuirlo  e/o
  modificarlo secondo i  termini della Licenza Pubblica Generica GNU
  come e` pubblicata dalla Free Software Foundation; o la versione 2
  della licenza o (a propria scelta) una versione successiva.

  Questo programma  e` distribuito nella speranza  che sia utile, ma
  SENZA   ALCUNA GARANZIA; senza  neppure  la  garanzia implicita di
  NEGOZIABILITA` o di  APPLICABILITA` PER UN  PARTICOLARE SCOPO.  Si
  veda la Licenza Pubblica Generica GNU per avere maggiori dettagli.

  Ognuno dovrebbe avere   ricevuto una copia  della Licenza Pubblica
  Generica GNU insieme a   questo programma; in caso  contrario,  si
  scriva   alla   Free  Software Foundation, 51 Franklin Street,
  Fifth Floor Boston, MA 02110-1335 USA Stati Uniti.
  --------------------------------------------------------------------------
 */
$transl['contab'] = array('name' => "Accounting",
    'title' => "Accounting and VAT management",
    'm2' => array(1 => array("General ledger and V.A.T. transaction", "G.L. transaction"),
        2 => array("Chart of Accounts", "Chart of Accounts"),
        3 => array("Accounting Causal management", "Accounting Causal"),
        4 => array("View and print VAT reports book", "VAT reports book"),
        5 => array("View and print VAT balance", "VAT balance"),
        6 => array("View and print General Ledger", "General Ledger"),
        7 => array("Visualizzazione e stampa della situazione contabile", "Situazione contabile")
    ),
    'm3' => array(1 => array("Enter a new movement accounting", "New movement"),
        2 => array("Insert new account", "New account"),
        3 => array("View and/or print account reports", "Account report"),
        4 => array("Insert new accounting causal", "New accounting causal"),
        5 => array("Print the chart of accounts", "Print the chart of accounts"),
        6 => array("Visualizzazione e stampa di estratti conto o partite aperte", "Estratti Conto/Partite Aperte"),
        7 => array("View and print credit/debit customers/suppliers", "Debit/Credit review"),
        8 => array("Spesometro analitico", "Spesometro analitico"),
        9 => array("File XML per Comunicazioni liquidazioni IVA", "Lista File Comunicazioni liquidazioni IVA"),
        10 => array("File XML per Comunicazione dati fatture", "Comunicazione dati fatture"),
        11 => array("Visualizzazione e stampa del registro riepilogativo I.V.A.", "Liquidazione IVA"),
        12 => array("File XML per Comunicazioni dati fatture", "Lista File Comunicazioni dati fatture"),
        13 => array("Visualizza i corrispettivi giornalieri", "Registro Corrispettivi"),
        14 => array( "Files XML per Comunicazioni dati fatture da e verso stranieri", "Esterometro")
    )
);
?>

==> gazie8.00.zip: gazie/modules/contab/menu.english.php <==
<?php
/*
  --------------------------------------------------------------------------
  GAzie - Gestione Azienda
  Copyright (C) 2004-2021 - Antonio De Vincentiis Montesilvano (PE)
  (http://www.devincentiis.it)
  <http://gazie.sourceforge.net>
  --------------------------------------------------------------------------
  Questo programma e` free software;   e` lecito redistribuirlo  e/o
  modificarlo secondo i  termini della Licenza Pubblica Generica GNU
  come e` pubblicata dalla Free Software Foundation; o la versione 2
  della licenza o (a propria scelta) una versione successiva.

  Questo programma  e` distribuito nella speranza  che sia utile, ma
  SENZA   ALCUNA GARANZIA; senza  neppure  la  garanzia implicita di
  NEGOZIABILITA` o di  APPLICABILITA` PER UN  PARTICOLARE SCOPO.  Si
  veda la Licenza Pubblica Generica GNU per avere maggiori dettagli.

  Ognuno dovrebbe avere   ricevuto una copia  della Licenza Pubblica
  Generica GNU insieme a   questo programma; in caso  contrario,  si
  scriva   alla   Free  Software Foundation, 51 Franklin Street,
  Fifth Floor Boston, MA 02110-1335 USA Stati Uniti.
  --------------------------------------------------------------------------
 */
$transl['contab'] = array('name' => "Accounting",
    'title' => "Accounting and VAT management",
    'm2' => array(1 => array("General ledger and V.A.T. transaction", "G.L. transaction"),
        2 => array("Chart of Accounts", "Chart of Accounts"),
        3 => array("Accounting Causal management", "Accounting Causal"),
        4 => array("View and print VAT reports book", "VAT reports book"),
        5 => array("View and print VAT balance", "VAT balance"),
        6 => array("View and print General Ledger", "General Ledger"),
        7 => array("Visualizzazione e stampa della situazione contabile", "Situazione contabile")
    ),
    'm3' => array(1 => array("Enter a new movement accounting", "New movement"),
        2 => array("Insert new account", "New account"),
        3 => array("View and/or print account reports", "Account report"),
        4 => array("Insert new accounting causal", "New accounting causal"),
        5 => array("Print the chart of accounts", "Print the chart of accounts"),
        6 => array("Visualizzazione e stampa di estratti conto o partite aperte", "Estratti Conto/Partite Aperte"),
        7 => array("View and print credit/debit customers/suppliers", "Debit/Credit review"),
        8 => array("Spesometro analitico", "Spesometro analitico"),
        9 => array("File XML per Comunicazioni liquidazioni IVA", "Lista File Comunicazioni liquidazioni IVA"),
        10 => array("File XML per Comunicazione dati fatture", "Comunicazione dati fatture"),
        11 => array("Visualizzazione e stampa del registro riepilogativo I.V.A.", "Liquidazione IVA"),
        12 => array("File XML per Comunicazioni dati fatture", "Lista File Comunicazioni dati fatture"),
        13 => array("Visualizza i corrispettivi giornalieri", "Registro Corrispettivi"),
        14 => array( "Files XML per Comunicazioni dati fatture da e verso stranieri", "Esterometro"),
        15 => array( "Riconciliazione E/C bancario", "Riconciliazione E/C")
    )
);
?>
